@@ -1,12 +1,13 @@
 # Copyright (c) 2020, Riverbank Computing Limited
 # All rights reserved.
 #
-# This copy of SIP is licensed for use under the terms of the SIP License
-# Agreement.  See the file LICENSE for more details.
+# This copy of PyQt-builder is licensed for use under the terms of the SIP
+# License Agreement.  See the file LICENSE for more details.
 #
-# This copy of SIP may also used under the terms of the GNU General Public
-# License v2 or v3 as published by the Free Software Foundation which can be
-# found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
+# This copy of PyQt-builder may also used under the terms of the GNU General
+# Public License v2 or v3 as published by the Free Software Foundation which
+# can be found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this
+# package.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -146,7 +147,7 @@ _QT_METADATA = {
         VersionedMetadata(),
 
     'QtRemoteObjects':
-        VersionedMetadata(version=(5, 12, 0)),
+        VersionedMetadata(version=(5, 12, 0), qml=True),
 
     'QtSensors':
         VersionedMetadata(qml=True),
@@ -163,6 +164,9 @@ _QT_METADATA = {
     'QtTest':
         VersionedMetadata(qml=True),
 
+    'QtTextToSpeech':
+        VersionedMetadata(version=(5, 15, 0)),
+
     'QtWebChannel':
         VersionedMetadata(qml=True),
 
